<?php

function drawAdminTools_AddDomain($admin){
	global $adm_login;
	global $adm_pass;
	global $addrlink;

	global $registration_added_price;

	global $form_enter_dns_infos;
	global $form_enter_domain_name;
	global $whois_forwareded_params;
	global $form_period_popup;
	global $conf_webmaster_email_addr;
	global $conf_use_registrar_api;
	global $pro_mysql_pending_queries_table;
	global $pro_mysql_domain_table;
	global $pro_mysql_client_table;
	global $pro_mysql_product_table;

	global $secpayconf_currency_letters;
	global $pro_mysql_handle_table;

	get_secpay_conf();

	$out = "";

$form_start = "
<form action=\"".$_SERVER["PHP_SELF"]."\">
<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
<input type=\"hidden\" name=\"action\" value=\"dtcrm_add_domain\">
";

	// User is trying to add a new service, let's complete the form!
	if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_new_service"){
		if(!isRandomNum($_REQUEST["product_id"])){
			$out .= _("The product ID is not a valid integer number.");
			return $out;
		}
		$q = "SELECT * FROM $pro_mysql_product_table WHERE id='".$_REQUEST["product_id"]."';";
		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
                $n = mysql_num_rows($r);
                if($n != 1){
                	$out .= _("Cannot reselect product: registration failed!") ;
                	return $out;
                }
                $product = mysql_fetch_array($r);
			switch($product["heb_type"]){
			default:
			case "shared":  // -> Something has to be done to select dedicated servers location in the form !!!
			case "server":
				$added1 = "<input type=\"hidden\" name=\"vps_location\" value=\"node0001.example.com\">
<input type=\"hidden\" name=\"vps_os\" value=\"debian\">";
				break;
			case "vps":
				$added1 = _("VPS location: ")."<select name=\"vps_location\">".vpsLocationSelector()."</select><br>".
				_("VPS OS: ")."<select name=\"vps_os\">
<option value=\"debian\">Debian</option>
<option value=\"centos\">CentOS</option>
<option value=\"gentoo\">Gentoo</option>
<option value=\"netbsd\">NetBSD</option>
</select><br>";
				break;
			}
		$out .= "<br><br><h3>"._("Add another service to your account:")."</h3>".
"<br><form action=\"/dtc/new_account.php\">
<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
<input type=\"hidden\" name=\"product_id\" value=\"".$_REQUEST["product_id"]."\">
<input type=\"hidden\" name=\"action\" value=\"add_new_service\">".$added1."
Special notes for the setup:<textarea name=\"custom_notes\" cols=\"50\" rows=\"5\"></textarea><br>
<input type=\"submit\" value=\""._("Register")."\">
";
		
		return $out;
	}

	// Registration, hosting, or both ?
	if(!isset($_REQUEST["add_domain_type"]) || ($_REQUEST["add_domain_type"] != "domregandhosting" &&
		$_REQUEST["add_domain_type"] != "domreg" &&
		$_REQUEST["add_domain_type"] != "hosting")){
		$out .= "<br><h3>". _("What do you want to add:") ."</h3>
$form_start";
		if($conf_use_registrar_api == "yes"){
			$out .= "<input type=\"radio\" name=\"add_domain_type\" value=\"domregandhosting\" checked>". _("Hosting + domain name registration or transfer")."<br>";
			$add_domain_type_checked = " ";
		}else{
			$add_domain_type_checked = " checked ";
		}
		$out .= "<input type=\"radio\" name=\"add_domain_type\" value=\"hosting\" checked>". _("Hosting only") ."<br>
<input type=\"submit\" value=\"Ok\">
</form>
";


		$out .= "<br><br><h3>"._("Add another service to your account:")."</h3>";
		if( isset($admin["data"])){
			$added_conditions = " AND heb_type NOT LIKE 'shared' ";
		}else{
			$added_conditions = "";
		}
		$q = "SELECT * FROM $pro_mysql_product_table WHERE private='no' AND renew_prod_id='0' AND heb_type NOT LIKE 'ssl' $added_conditions;";
		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
		$n = mysql_num_rows($r);
		for($i=0;$i<$n;$i++){
			$a = mysql_fetch_array($r);
//			if($i > 0){
//				$out .= " - ";
//			}
			$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
			<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
			<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
			<input type=\"hidden\" name=\"action\" value=\"add_new_service\">
			<input type=\"hidden\" name=\"product_id\" value=\"".$a["id"]."\">
			<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
			<input type=\"submit\" value=\"".$a["name"]."\"></form>";
//			$out .= "<a href=\"/dtc/new_account.php?action=add_new_service&adm_login=$adm_login&product_id=".$a["id"]."\">".$a["name"]."</a>";
		}
		return $out;
	}
	$form_start .= "<input type=\"hidden\" name=\"add_domain_type\" value=\"".$_REQUEST["add_domain_type"]."\">";
//	$form_start .= "<input type=\"hidden\" name=\"add_domain_type\" value=\"domregandhosting\">";
	if($_REQUEST["add_domain_type"] == "hosting"){
		// The don't want name registration or transfer,
		// Simply add the domain.
		if($admin["info"]["allow_add_domain"] == "no"){
			return _("You curently don't have enough privileges to add domain names. If you often add domain names, you can ask the administrator to do so. To request hosting for a new domain without domain name registration, please write to:")."<br>".
"<a href=\"mailto:$conf_webmaster_email_addr?subject=[DTC] More domains\">$conf_webmaster_email_addr</a>.";
		}
		if(!isset($_REQUEST["domain_name"]) || $_REQUEST["domain_name"] == ""){
			return "<br><b><u>". _("Please enter the domain name you wish to add:") ."</u></b><br>
$form_start<input type=\"text\" name=\"domain_name\" value=\"\">
<input type=\"submit\" value=\"ok\"></form>";
		}
		if(!isHostname($_REQUEST["domain_name"])){
			return _("Domain name is not in correct format. Please enter another name.") ;
		}
		$q = "SELECT * FROM $pro_mysql_domain_table WHERE name='".$_REQUEST["domain_name"]."';";
		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
		$n = mysql_num_rows($r);
		if($n > 0){
			return _("This domain name already hosted here, please enter another name.") ;
		}
		if($admin["info"]["allow_add_domain"] == "check"){
			$q = "INSERT INTO $pro_mysql_pending_queries_table (adm_login,domain_name,date) VALUES ('$adm_login','".$_REQUEST["domain_name"]."','".date("Y-m-d H:i")."');";
			$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
			return "<br><u><b>". _("Your domain name will be soon validated:") ."</b></u><br>".
			_("An administrator will examine your request shortly, and validate the addition of this domain name to your account. You curently don't have enough privileges to add domain names. If you often add domain names, you can ask the administrator to grant you the privilege of automatic domain name addition. To request hosting for a new domain name, without administrator validation or domain name registration, please write to:") ."<br>
<a href=\"$conf_webmaster_email_addr?subject=[DTC] More domains\">$conf_webmaster_email_addr</a>.<br>
<br>
". _("You can add another domain name:") ."
$form_start<input type=\"text\" name=\"domain_name\" value=\"\">
<input type=\"submit\" value=\"ok\"></form>
";
		}
		addDomainToUser($adm_login,$adm_pass,$_REQUEST["domain_name"]);
		return "<br><u><b>". _("Your domain name is now ready:") ."</b></u><br>
". _("Now you can go to check its configuration by clicking here:") ."<br>
<a href=\"".$_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=".$_REQUEST["domain_name"]."\">".$_REQUEST["domain_name"]."</a><br>
<br>
". _("Alternatively, you can add another domain name:") ."
$form_start<input type=\"text\" name=\"domain_name\" value=\"\">
<input type=\"submit\" value=\"ok\"></form>
";
	}

	// Registration or domain transfer ?
	if(!isset($_REQUEST["add_regortrans"]) || ($_REQUEST["add_regortrans"] != "register" &&
		$_REQUEST["add_regortrans"] != "transfer")){
		$out .= "<b><u>". _("Do you want to transfer an existing domain or register a new domain?") ."</u></b><br>
$form_start
<input type=\"radio\" name=\"add_regortrans\" value=\"register\" checked>". _("Register a new domain") ."<br>
<input type=\"radio\" name=\"add_regortrans\" value=\"transfer\">". _("Transfer an existing domain from another registrar") ."<br>
<input type=\"submit\" value=\"Ok\">
</form>
";
		return $out;
	}
	if($_REQUEST["add_regortrans"] == "transfer") return drawNameTransfer($admin);
	$form_start .= "<input type=\"hidden\" name=\"add_regortrans\" value=\"register\">";

	// Start registration procedure (with or without hosting)

	$out .= "<b><u>". _("Register a domain name") ."</u></b><br>";
	$out .= "<i><u>". _("Step 1: Verify availability") ."</u></i><br>";
	if(!isset($_REQUEST["toreg_domain"]) || $_REQUEST["toreg_domain"] == "" ||
	!isset($_REQUEST["toreg_extention"]) || $_REQUEST["toreg_extention"] == ""){
		$out .= "<br>". _("Enter the domain name you want to register:") ."<br>
$form_start $form_enter_domain_name</form>";
		return $out;
	}

	$fqdn = $_REQUEST["toreg_domain"] . $_REQUEST["toreg_extention"];
	$domlookup = registry_check_availability($fqdn);
	if($domlookup["is_success"] != 1){
		$out .= "<font color=\"red\">". _("Could not connect to domain registration server: please try again later!") 
			."</font><br>".$domlookup['response_text'];
		return $out;
	}

	if($domlookup["attributes"]["status"] != "available"){
		$out .= "<br>
". _("Sorry, the domain name ") ." <b>$fqdn</b> ". _("is NOT available for registration. The registration server returned: ") 
."<br><font color=\"red\">" . $domlookup["response_text"] . "</font>
<br><br>
Have another try:<br>$form_start $form_enter_domain_name</form>";
		return $out;
	}
	$form_start .= "<input type=\"hidden\" name=\"toreg_domain\" value=\"".$_REQUEST["toreg_domain"]."\">
<input type=\"hidden\" name=\"toreg_extention\" value=\"".$_REQUEST["toreg_extention"]."\">";

	// DOMAIN IS AVAILABLE, PROCEED DO REGISTRATION
	$out .= "Domain name <b>$fqdn</b> is available for registration.<br><br>
<i><u>". _("Step 2: Enter whois information") ."</u></i><br>
";
//http://dtc.example.com/dtc/index.php?adm_login=dtc&adm_pass=bemybest&
//addrlink=myaccount%2Fadddomain&
//action=dtcrm_add_domain&add_domain_type=domreg&add_regortrans=register&
//toreg_domain=yugluxrfvcd&toreg_extention=.com&
//dtcrm_owner_hdl=1&dtcrm_billing_hdl=1&dtcrm_admin_hdl=1&
//toreg_dns1=default&toreg_dns2=default&
//toreg_period=1
	if(!isset($_REQUEST["dtcrm_owner_hdl"]) || $_REQUEST["dtcrm_owner_hdl"] == "" ||
		!isset($_REQUEST["dtcrm_admin_hdl"]) || $_REQUEST["dtcrm_admin_hdl"] == "" ||
		!isset($_REQUEST["dtcrm_billing_hdl"]) || $_REQUEST["dtcrm_billing_hdl"] == "" ||
		!isset($_REQUEST["toreg_dns1"]) || $_REQUEST["toreg_dns1"] == "" ||
		!isset($_REQUEST["toreg_dns2"]) || $_REQUEST["toreg_dns2"] == "" ||
		$_REQUEST["toreg_period"] < 1 || $_REQUEST["toreg_period"] > 10){

		$year = _("year") ;
		$years = _("years") ;
		$out .= _("Please select the 3 contact handles you want to use for registering that domain name.") ."<br><br>$form_start";
		$out .= whoisHandleSelection($admin);
		$out .= "<br>$form_enter_dns_infos<br><br>
". _("Select how long you want to register this domain name:") ."<br>
<select name=\"toreg_period\">
<option value=\"1\">1 $year</option>
<option value=\"2\">2 $years</option>
<option value=\"3\">3 $years</option>
<option value=\"4\">4 $years</option>
<option value=\"5\">5 $years</option>
<option value=\"6\">6 $years</option>
<option value=\"7\">7 $years</option>
<option value=\"8\">8 $years</option>
<option value=\"9\">9 $years</option>
<option value=\"10\">10 $years</option>
</select><br><br>
<input type=\"submit\" value=\"Ok\">
</form>
";
		return $out;
	}
	$form_start .= "$whois_forwareded_params
<input type=\"hidden\" name=\"toreg_period\" value=\"".$_REQUEST["toreg_period"]."\">";

	$out .= "Registration for <b>" . $_REQUEST["toreg_period"] . " years</b><br>";
	$out .= "DNS1: " . $_REQUEST["toreg_dns1"] . "<br>";
	$out .= "DNS2: " . $_REQUEST["toreg_dns2"] . "<br><br>";
	$out .= "<i><u>". _("Step 3: Proceed to registration") ."</u></i>
$form_start
";

	// Check if paiement has just occured !
	if(isset($_REQUEST["inner_action"]) && $_REQUEST["inner_action"] == "return_from_paypal_domain_add"){
		$ze_refund = isPayIDValidated(addslashes($_REQUEST["pay_id"]));
		if($ze_refund == 0){
			$out .= "<font color=\"red\">The transaction failed, please try again!</font>";
		}else{
			$out .= "<font color=\"green\">Funds added to your account</font>";
			$q = "UPDATE $pro_mysql_client_table SET dollar = dollar+".$ze_refund." WHERE id='".$admin["info"]["id_client"]."';";
			$r = mysql_query($q)or die("Cannot querry $q line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
			$admin["client"]["dollar"] += $ze_refund;
		}
	}

	// Check billing to know if user has enough money on his account
	$price = registry_get_domain_price($fqdn,$_REQUEST["toreg_period"]);
	$fqdn_price = $price["attributes"]["price"] + $registration_added_price;
	$fqdn_price *= $_REQUEST["toreg_period"];

	if($admin["info"]["id_client"] != 0){
		$remaining = $admin["client"]["dollar"];
	}else{
		$out .= _("You don't have a client ID. Please contact us.") ."<br>";
		$remaining = 0;
		return $out;
	}
	$out .= _("Remaining on your account: ") ." $secpayconf_currency_letters" . $remaining . "<br>
". _("Total price: ") ." \$". $fqdn_price . "<br><br>";
	if($fqdn_price > $remaining){
		$to_pay = $fqdn_price - $remaining;

		$payid = createCreditCardPaiementID($to_pay,$admin["info"]["id_client"],
				"Domain name registration ".$_REQUEST["toreg_extention"],"no");
		$return_url = $_SERVER["PHP_SELF"]."?adm_login=$adm_login&adm_pass=$adm_pass"
		."&addrlink=$addrlink&action=dtcrm_add_domain&add_domain_type=".$_REQUEST["add_domain_type"]
		."&add_regortrans=".$_REQUEST["add_regortrans"]."&toreg_domain=".$_REQUEST["toreg_domain"]
		."&toreg_extention=".$_REQUEST["toreg_extention"]."&dtcrm_owner_hdl=".$_REQUEST["dtcrm_owner_hdl"]
		."&dtcrm_admin_hdl=".$_REQUEST["dtcrm_admin_hdl"]."&dtcrm_billing_hdl=".$_REQUEST["dtcrm_billing_hdl"]
		."&toreg_dns1=".$_REQUEST["toreg_dns1"]."&toreg_dns2=".$_REQUEST["toreg_dns2"]
		."&toreg_dns3=".$_REQUEST["toreg_dns3"]."&toreg_dns4=".$_REQUEST["toreg_dns4"]
		."&toreg_dns5=".$_REQUEST["toreg_dns5"]."&toreg_dns6=".$_REQUEST["toreg_dns6"]
		."&toreg_period=".$_REQUEST["toreg_period"]."&inner_action=return_from_paypal_domain_add&payid=$payid";
		$paybutton = paynowButton($payid,$to_pay,
				"Domain name registration ".$_REQUEST["toreg_extention"],$return_url);

		$out .= _("You currently don't have enough funds on your account. You will be redirected to our payment system. Please click on the button below to pay.") ."<br>
<br><br>
$form_start<input type=\"submit\" value=\"". _("Payment complete. Proceed to checkout") ."\">
</form> $paybutton";
		return $out;
	}

	// Check for confirmation
	if(!isset($_REQUEST["toreg_confirm_register"]) || $_REQUEST["toreg_confirm_register"] != "yes"){
		$out .= _("You have enough funds on your account to proceed with registration. Press the confirm button to proceed.") ."<br><br>
$form_start
<input type=\"hidden\" name=\"toreg_confirm_register\" value=\"yes\">
<input type=\"submit\" value=\"". _("Proceed to name-registration") ."\">
</form>";
		return $out;
	}
///////////////////////////////////////
// START OF DOMAIN NAME REGISTRATION //
	$owner_id = $_REQUEST["dtcrm_owner_hdl"];
	$billing_id = $_REQUEST["dtcrm_billing_hdl"];
	$admin_id = $_REQUEST["dtcrm_admin_hdl"];
	$contacts = getContactsArrayFromID($owner_id,$billing_id,$admin_id);
	$regz = registry_register_domain($adm_login,$adm_pass,$fqdn,$_REQUEST["toreg_period"],$contacts,$dns_servers);

	if($regz["is_success"] != 1){
		$out .= "<font color=\"red\"><b>". _("Registration failed") ."</b></font><br>
". _("Server said: ") ."<i>" . $regz["response_text"] . "</i>";
		return $out;
	}
	$out .= "<font color=\"green\"><b>Registration succesfull</b></font><br>
Server said: <i>" . $regz["response_text"] . "</i><br>";

	$operation = $remaining - $fqdn_price;
	$query = "UPDATE $pro_mysql_client_table SET dollar='$operation' WHERE id='".$admin["info"]["id_client"]."';";
	mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());

	addDomainToUser($adm_login,$adm_pass,$fqdn,$adm_pass);
	unset($ns_ar);
	$ns_ar[] = $_REQUEST["toreg_dns1"];
	$ns_ar[] = $_REQUEST["toreg_dns2"];
	if(isset($_REQUEST["toreg_dns3"]) && $_REQUEST["toreg_dns3"] != "")
		$ns_ar[] = $_REQUEST["toreg_dns3"];
	if(isset($_REQUEST["toreg_dns4"]) && $_REQUEST["toreg_dns4"] != "")
		$ns_ar[] = $_REQUEST["toreg_dns4"];
	if(isset($_REQUEST["toreg_dns5"]) && $_REQUEST["toreg_dns5"] != "")
		$ns_ar[] = $_REQUEST["toreg_dns5"];
	if(isset($_REQUEST["toreg_dns6"]) && $_REQUEST["toreg_dns6"] != "")
		$ns_ar[] = $_REQUEST["toreg_dns6"];
	newWhois($fqdn,$owner_id,$billing_id,$admin_id,$period,$ns_ar);

	$out .= "<font color=\"green\"><b>". _("Successfully added your domain name to the hosting database") ."</b></font><br>";

	$out .= _("Click") ."<a href=\"". $_SERVER["PHP_SELF"] ."?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=$addrlink\">". _("here") ."</a>". _("to refresh the menu or add another domain name.") ;

// END OF DOMAIN NAME REGISTRATION //
/////////////////////////////////////


	return $out;
}


?>
